@@ -12,10 +12,10 @@ class Dependency:
         self.path = self.manager.path
 
     def list(self, path=None):
-        return self.manager.list_prod(None, path)
+        return self.manager.list_prod("list_history", path)
 
-    def get(self, path=None):
-        return self.manager.get_file(path)
+    def get(self, path=None, histo=None):
+        return self.manager.get_file(path, histo=histo)
 
     def clear(self, path=None, histo=None):
         return self.manager.clear_file(path, None, histo)
@@ -34,7 +34,7 @@ class Dependency:
     def add(self, path=None, debug=False):
         if self.manager.is_production():
             print("No add done you are in production\n")
-            return self.get_prod_path(path)
+            return self.get_path(path)
         current_file = self.manager.get_path(path)
         self.manager.add_prod(
             {
@@ -47,7 +47,7 @@ class Dependency:
         )
         print("👌 Well done! Your Dependency has been sent to production. \n")
         print('PS: to remove the "Dependency" feature, just replace .add by .delete')
-        return self.get_prod_path(current_file)
+        return self.get_path(current_file)
 
     def delete(self, path=None, all=False, debug=False):
         if self.manager.is_production():
