@@ -23,7 +23,10 @@ def parse_data(request):
     elif request.headers.get("content-type") == "application/x-www-form-urlencoded":
         req_data = dict(urllib.parse.parse_qsl(request.body.decode("utf-8")))
     req_data = rename_keys(req_data)
-    data = {**(request.args), **(req_data)}
+    args = dict(
+        urllib.parse.parse_qsl(request.query_string)
+    )  # fix to don't have array for each args
+    data = {**(args), **(req_data)}
     return data
 
 
@@ -42,7 +45,8 @@ class NbController(HTTPMethodView):
         if task:
             value = task.get("value", None)
             file_filepath = task.get("path")
-            task["params"] = {**(task.get("params", dict())), **(data)}
+            cur_task = task.copy()
+            cur_task["params"] = {**(task.get("params", dict())), **(data)}
             self.__logger.info(
                 {
                     "id": uid,
@@ -55,7 +59,7 @@ class NbController(HTTPMethodView):
             await self.__jobs.update(
                 uid, file_filepath, t_notebook, value, task.get("params"), t_start
             )
-            res = await self.__nb.exec(uid, task)
+            res = await self.__nb.exec(uid, cur_task)
             if res.get("error"):
                 self.__logger.error(
                     {
@@ -65,7 +69,7 @@ class NbController(HTTPMethodView):
                         "status": t_error,
                         "filepath": file_filepath,
                         "duration": res.get("duration"),
-                        "error": res.get("error"),
+                        "error": str(res.get("error")),
                     }
                 )
                 await self.__jobs.update(
@@ -83,7 +87,6 @@ class NbController(HTTPMethodView):
                         "error": res.get("error"),
                         "data": data,
                         "token": token,
-                        "traceback": res.get("traceback"),
                     },
                     status_code=500,
                 )
